@@ -7,6 +7,8 @@ alias @assets=bluer_sandbox_assets
 
 alias @docker=bluer_sandbox_docker
 
+alias @interview=bluer_sandbox_interview
+
 alias @notebooks=bluer_sandbox_notebooks
 
 alias @parser=bluer_sandbox_parser
@@ -19,4 +21,6 @@ alias @sandbox=bluer_sandbox
 
 alias @speedtest=bluer_sandbox_speedtest
 
-alias @tor=bluer_sandbox_tor
\ No newline at end of file
+alias @tor=bluer_sandbox_tor
+
+alias @village=bluer_sandbox_village
