@@ -4,6 +4,7 @@ load_env(__name__)
 load_config(__name__)
 
 
-BLUER_SANDBOX_CONFIG = get_env("BLUER_SANDBOX_CONFIG")
-
 ARVANCLOUD_PRIVATE_KEY = get_env("ARVANCLOUD_PRIVATE_KEY")
+
+BLUER_VILLAGE_OBJECT = get_env("BLUER_VILLAGE_OBJECT")
+BLUER_VILLAGE_TEST_OBJECT = get_env("BLUER_VILLAGE_TEST_OBJECT")
