@@ -6,11 +6,6 @@ from IPython.display import display, HTML
 
 from bluer_objects import storage, mlflow
 
-os.environ["MLFLOW_TRACKING_URI"] = os.path.join(
-    os.environ.get("HOME"),
-    "mlflow",
-)
-
 
 def get_image_base64(filename):
     with open(filename, "rb") as f:
@@ -52,5 +47,19 @@ def imshow(
         display(HTML(html))
 
 
-def upload(object_name: str) -> bool:
-    return storage.upload(object_name) and mlflow.log_run(object_name)
+def upload(
+    object_name: str,
+    public: bool = False,
+    zip: bool = False,
+) -> bool:
+    if not storage.upload(
+        object_name=object_name,
+        public=public,
+        zip=zip,
+    ):
+        return False
+
+    if public or zip:
+        return True
+
+    return mlflow.log_run(object_name)
